#------------------------------------------------- {COPYRIGHT-TOP-RM}
# Licensed Materials - Property of IBM
#
# "Restricted Materials of IBM"
#
# 5724-C51
#
# (C) Copyright IBM Corp. 1999,2004 All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#------------------------------------------------- {COPYRIGHT-END-RM}
# File: archive/scripts/exportlobasxml.sh, tbsm_base, tbsm_base31e
# SID: 1.16
# Date Modified: 09/03/26 07:24:45
#
# Module Description:
#   Script wrapper for calling procedure asisp_exportLOBAsXML

#
# Usage
#
function Usage
{
  ASIShellMsg ASIMiscScripts 87 "exportlobasxml"
  ASIShellMsg ASIMiscScripts 89
  ASIShellMsg ASIMiscScripts 90
  ASIShellMsg ASIMiscScripts 91
  ASIShellMsg ASIMiscScripts 92
  ASIShellMsg ASIMiscScripts 93
  ASIShellMsg ASIMiscScripts 166
  ASIShellMsg ASIMiscScripts 95
  ASIShellMsg ASIMiscScripts 96
  ASIShellMsg ASIMiscScripts 97
  ASIShellMsg ASIMiscScripts 165
  ASIShellMsg ASIMiscScripts 98
  ASIShellMsg ASIMiscScripts 167
  ASIShellMsg ASIMiscScripts 102

#  print "Usage:"
#  print ""
#  print "  sh ExportLOBAsXML -S<DB Server> -U<DB User> -P<DB Password> -f<Output File Path> [-c<Class ID> -i<Object ID>] | -m<count>"
#  print ""
#  print "  Database Parameters:"
#  print ""
#  print "    -S<DB Server>:   The name of the server where the database resides"
#  print "    -U<DB User>:     The username to access the database"
#  print "    -P<DB Password>: The password to acesss the database"
#  print ""
#  print "  Other parameters:"
#  print ""
#  print "    -f<Output File Path>:   The file path to contain the XML data.  Should be delimited using forward slashes (/)."
#  print "    -c<Class ID>:           The cid of the starting resource. Used with the -i parameter.  Default is NULL."
#  print "    -i<Object ID>:          The id of the starting resource. Used with the -c parameter. Default is NULL"
#  print "    -m<count>               Specifies the maximum number of files to be stored in the export directory.  A negative value displays the current setting."
#  print "    -a:                     Optional. Use -a to Add the Physical or Locigal Name to LOB InstId
#  print "  If the Class ID and Object ID parameters are NULL, the entire Business System tree is extracted."


}

#
# CheckRequiredParams
#
function CheckRequiredParams
{
  # Check the database params
  if [ -z "$server_opt" ]; then
    ASIShellMsg ASIMiscScripts 69 "-S<DB Server>"
    Usage >&2
    exit 2
  elif [ -z "$e_opt" ]; then
      if [ -z "$user_opt" ]; then
        sql_opt="-S$server_opt -E"
      elif [ -z "$password_opt" ]; then
          ASIShellMsg ASIMiscScripts 69 "-P<DB Password>"
          Usage >&2
          exit 2
        else
          sql_opt="-S$server_opt -U$user_opt -P$password_opt"
      fi
    else      
      sql_opt="-S$server_opt -E"
  fi

  # We must have either -m or -f
  if [ -z "$sFileCount" -a -z "$sFilePath" ]; then
    ASIShellMsg ASIMiscScripts 169
    exit 2
  fi  

  # We should not have both -m and -f
  if [ ! -z "$sFileCount" -a  ! -z "$sFilePath" ]; then
    ASIShellMsg ASIMiscScripts 169
    exit 2
  fi  

  if [ ! -z "$sFileCount" ]; then
    # Verify that the -m parameter is numeric, if specified
    nFileCountNeg=$(echo "$sFileCount" | grep "^[-][0-9][0-9]*$")
    nFileCount=$(echo "$sFileCount" | grep "^[0-9][0-9]*$")
    if [ -z "$nFileCount" -a -z "$nFileCountNeg" ]; then
      print >&2 "ERROR: The -m parameter is not numeric."
      ASIShellMsg ASIMiscScripts 128
      Usage >& 2
      exit 2
    else
      if [ "$sFileCount" = "0" ] ; then
        nFileCountNeg="0"
      fi  
    fi
  fi

  # Check the name
  if [ ! -z "$sName" ] ; then
    if [ ! -z "$sCIDArg" -o ! -z "$sIDArg" ]; then
      ASIShellMsg ASIMiscScripts 168
      exit 2
    fi
  else
    # Check the cid / id parameters
    if [ ! -z "$sCIDArg" -o ! -z "$sIDArg" ]; then
      if [ -z "$sCIDArg" -o -z "$sIDArg" ]; then
        #print >&2 "ERROR: Must use -c and -i together to define the starting resource."
        ASIShellMsg ASIMiscScripts 100
        Usage >& 2
        exit 2
      fi
    
      # Verify that the -i parameter is numeric
      if [ -z $nIDArg ]; then
        #print >&2 "ERROR: The -i parameter is not numeric."
        ASIShellMsg ASIMiscScripts 101
        Usage >& 2
        exit 2
      fi
    fi
  fi  
}


#
# main
#

server_opt=$tbsm_server
user_opt=$tbsm_userid
password_opt=$tbsm_password
e_opt=""
sFileCount=""
sCIDArg=""
sIDArg=""
sName=""

# Get the database connection info from the registry
eval $(regdmp 'HKEY_LOCAL_MACHINE\SOFTWARE\Accessible Software, Inc.\Access1\1.0\Settings\DB' | awk '/Server/ {printf("export reg_server=\"%s\"\n",$3);} /User/ {printf("export reg_userid=\"%s\"\n",$3);} /Password/ {printf("export reg_password=\"%s\"\n",$3)}')
# Check if any of the predefined environment variables have been set
if   [ -z "$tbsm_server" ]; then
    server_opt=$reg_server
fi
if   [ -z "$tbsm_userid" ]; then
    user_opt=$reg_userid
fi
if   [ -z "$tbsm_password" ]; then
    password_opt=$reg_password
fi

#
# process args
#
add_link=0

while getopts U:S:P:f:c:i:m:n:haE? c; do
  case $c in
  U)  user_opt="$OPTARG";;
  P)  password_opt="$OPTARG";;
  S)  server_opt="$OPTARG";;
  E)  e_opt=1;;
  f)  sFilePath="$OPTARG";;
  c)  sCIDArg=$(echo $OPTARG | awk '{print toupper($0)}');;
  i)  sIDArg=$OPTARG;;
  m)  sFileCount=$OPTARG;;
  a)  add_link=1;;
  n)  sName=$OPTARG;;
  h)  Usage; exit;;
  ?)  Usage; exit;;
  *)  Usage; exit;;
  esac
done

# Set Up Add Link To Instid Param
if [ $add_link -eq 1 ]; then
	add_link_param=", @addLinkToInstID=1 ";
fi


# Use trusted connection if db_user is empty
if [ -z "$user_opt" ]; then
  e_opt=1
fi

# Convert the sIDArg parameter to numeric.
if [ -n "$sIDArg" ] ; then
  nIDArg=$(echo "$sIDArg" | grep "^[0-9][0-9]*$")
fi

# check for required parameters.
CheckRequiredParams

# Get or set the export dir file max
if [ ! -z "$sFileCount" -a ! -z "$nFileCountNeg" ]; then

  sMaxFiles=$(  osql -b -n -w65535 $sql_opt <<- ENDSQL

  SET NOCOUNT ON
  DECLARE @val NVARCHAR(100)
  SELECT @val= propertyvalue FROM SystemConfiguration WHERE groupname = 'BusinessSystemExport' AND propertyname = 'MaxFiles'
  PRINT @val

ENDSQL
  )

  nMaxFiles=$(echo "$sMaxFiles" | grep "^[0-9][0-9]*$")

  if [ -z "$nMaxFiles" ]; then
    #print "The MaxFiles configuration value has not been set."
    ASIShellMsg ASIMiscScripts 129
  else
    #print "MaxFiles=$nMaxFiles"
    ASIShellMsg ASIMiscScripts 130 "$nMaxFiles"
  fi

elif [ ! -z "$sFileCount" -a ! -z "$nFileCount" ]; then
  osql -b -n -w65535 $sql_opt <<- ENDSQL

    SET NOCOUNT ON
    EXEC _SetSystemConfiguration NULL, NULL, 'BusinessSystemExport', 'MaxFiles', '$nFileCount', 'INT'

ENDSQL
fi

if [ ! -z "$sFilePath" ]; then
  if [ ! -z "$sName" ] ; then
    osql -b -n -w65535 $sql_opt <<- ENDSQL

      SET NOCOUNT ON
      EXEC asisp_exportLOBAsXML @path=N'$sFilePath', @name=N'$sName' $add_link_param

ENDSQL
  else
    if [ ! -z "$sCIDArg" ] ; then
      osql -b -n -w65535 $sql_opt <<- ENDSQL

        SET NOCOUNT ON
        EXEC asisp_exportLOBAsXML @cid='$sCIDArg', @id='$sIDArg', @path=N'$sFilePath' $add_link_param

ENDSQL
    else
      osql -b -n -w65535 $sql_opt <<- ENDSQL
   
        SET NOCOUNT ON
        EXEC asisp_exportLOBAsXML @path=N'$sFilePath' $add_link_param
   
ENDSQL
    fi 
  fi  
fi

